==> aql-2.0.0-sources.jar: org/ehrbase/openehr/sdk/aql/dto/condition/NotCondition.java <==
/*
 * Copyright (c) 2022 vitasystems GmbH and Hannover Medical School.
 *
 * This file is part of project openEHR_SDK
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ehrbase.openehr.sdk.aql.dto.condition;

import java.util.Objects;

/**
 * @author Stefan Spiska
 */
public class NotCondition implements WhereCondition {

    private WhereCondition condition;

    public NotCondition() {}

    public NotCondition(WhereCondition condition) {
        this.condition = condition;
    }

    public WhereCondition getConditionDto() {
        return condition;
    }

    public void setConditionDto(WhereCondition condition) {
        this.condition = condition;
    }

    @Override
    public String toString() {
        return "NotCondition{" + "condition=" + condition + '}';
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        NotCondition that = (NotCondition) o;
        return Objects.equals(condition, that.condition);
    }

    @Override
    public int hashCode() {
        return Objects.hash(condition);
    }
}

==> aql-2.4.0-sources.jar: org/ehrbase/openehr/sdk/aql/dto/condition/NotCondition.java <==
/*
 * Copyright (c) 2022 vitasystems GmbH and Hannover Medical School.
 *
 * This file is part of project openEHR_SDK
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ehrbase.openehr.sdk.aql.dto.condition;

import java.util.Objects;

/**
 * @author Stefan Spiska
 */
public class NotCondition implements WhereCondition {

    private WhereCondition condition;

    public NotCondition() {}

    public NotCondition(WhereCondition condition) {
        this.condition = condition;
    }

    public WhereCondition getConditionDto() {
        return condition;
    }

    public void setConditionDto(WhereCondition condition) {
        this.condition = condition;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        NotCondition that = (NotCondition) o;
        return Objects.equals(condition, that.condition);
    }

    @Override
    public int hashCode() {
        return Objects.hash(condition);
    }

    @Override
    public String toString() {
        return "NotCondition{" + "condition=" + condition + '}';
    }
}
